.. _ref-who-uses:

Sites Using django-planet
=========================

The following sites are a partial list of people using django-planet.
I'm always interested in adding more sites, so please find me (``matagus``)
via twitter or start a mailing list thread.

django-planet demo website:
---------------------------

Running on `Heroku`_:

* Site: https://django-planet.com/

.. _`Heroku`: http://heroku.com/
